@@ -9,17 +9,25 @@ pub struct UsnJrnl {
     entries: HashMap<KeyType, ValueType>
 }
 
-impl UsnJrnl {
-    pub fn new() -> Self {
+impl Default for UsnJrnl {
+    fn default() -> Self {
         Self {
             entries: HashMap::new()
         }
     }
+}
+
+impl UsnJrnl {
 
     pub fn len(&self) -> usize {
         self.entries.len()
     }
 
+    pub fn is_empty(&self) -> bool {
+        self.entries.is_empty()
+    }
+
+    #[allow(clippy::should_implement_trait)]
     pub fn into_iter(self) -> std::collections::hash_map::IntoIter<KeyType, ValueType> {
         self.entries.into_iter()
     }
@@ -34,7 +42,7 @@ impl From<UsnJrnlReader> for UsnJrnl {
                     match entries.get_mut(&data.FileReferenceNumber) {
                         Some(ref mut v) => v.push(entry),
                         None => {
-                            let _ = entries.insert(data.FileReferenceNumber.clone(), vec![entry]);
+                            let _ = entries.insert(data.FileReferenceNumber, vec![entry]);
                         }
                     };
                 }
